@@ -19,7 +19,7 @@
 // Copyright (C) 2007-2008, 2010, 2015 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2009 Till Kamppeter <till.kamppeter@gmail.com>
 // Copyright (C) 2009 Sanjoy Mahajan <sanjoy@mit.edu>
-// Copyright (C) 2009, 2011, 2012 William Bader <williambader@hotmail.com>
+// Copyright (C) 2009, 2011, 2012, 2014, 2015 William Bader <williambader@hotmail.com>
 // Copyright (C) 2010 Hib Eris <hib@hiberis.nl>
 // Copyright (C) 2012 Thomas Freitag <Thomas.Freitag@alfa.de>
 // Copyright (C) 2013 Suzuki Toshiya <mpsuzuki@hiroshima-u.ac.jp>
@@ -95,6 +95,7 @@ static GBool noEmbedTTFonts = gFalse;
 static GBool noEmbedCIDPSFonts = gFalse;
 static GBool noEmbedCIDTTFonts = gFalse;
 static GBool fontPassthrough = gFalse;
+static char rasterAntialiasStr[16] = "";
 static GBool preload = gFalse;
 static char paperSize[15] = "";
 static int paperWidth = -1;
@@ -154,6 +155,8 @@ static const ArgDesc argDesc[] = {
    "don't embed CID TrueType fonts"},
   {"-passfonts",  argFlag,        &fontPassthrough,0,
    "don't substitute missing fonts"},
+  {"-aaRaster",   argString,   rasterAntialiasStr, sizeof(rasterAntialiasStr),
+   "enable anti-aliasing on rasterization: yes, no"},
   {"-preload",    argFlag,     &preload,        0,
    "preload images and forms"},
   {"-paper",      argString,   paperSize,       sizeof(paperSize),
@@ -206,6 +209,7 @@ int main(int argc, char *argv[]) {
   GBool ok;
   char *p;
   int exitCode;
+  GBool rasterAntialias = gFalse;
   std::vector<int> pages;
 
   exitCode = 99;
@@ -293,35 +297,6 @@ int main(int argc, char *argv[]) {
   if (level1 || level1Sep || level2 || level2Sep || level3 || level3Sep) {
     globalParams->setPSLevel(level);
   }
-  if (splashResolution > 0) {
-    globalParams->setPSRasterResolution(splashResolution);
-  }
-  if (noEmbedT1Fonts) {
-    globalParams->setPSEmbedType1(!noEmbedT1Fonts);
-  }
-  if (noEmbedTTFonts) {
-    globalParams->setPSEmbedTrueType(!noEmbedTTFonts);
-  }
-  if (noEmbedCIDPSFonts) {
-    globalParams->setPSEmbedCIDPostScript(!noEmbedCIDPSFonts);
-  }
-  if (noEmbedCIDTTFonts) {
-    globalParams->setPSEmbedCIDTrueType(!noEmbedCIDTTFonts);
-  }
-  if (fontPassthrough) {
-    globalParams->setPSFontPassthrough(fontPassthrough);
-  }
-  if (preload) {
-    globalParams->setPSPreload(preload);
-  }
-#if OPI_SUPPORT
-  if (doOPI) {
-    globalParams->setPSOPI(doOPI);
-  }
-#endif
-  if (psBinary) {
-    globalParams->setPSBinary(psBinary);
-  }
   if (quiet) {
     globalParams->setErrQuiet(quiet);
   }
@@ -412,6 +387,28 @@ int main(int argc, char *argv[]) {
 			  paperHeight,
                           noCrop,
 			  duplex);
+
+  if (rasterAntialiasStr[0]) {
+    if (!GlobalParams::parseYesNo2(rasterAntialiasStr, &rasterAntialias)) {
+      fprintf(stderr, "Bad '-aaRaster' value on command line\n");
+    }
+  }
+
+  if (splashResolution > 0) {
+    psOut->setRasterResolution(splashResolution);
+  }
+  psOut->setEmbedType1(!noEmbedT1Fonts);
+  psOut->setEmbedTrueType(!noEmbedTTFonts);
+  psOut->setEmbedCIDPostScript(!noEmbedCIDPSFonts);
+  psOut->setEmbedCIDTrueType(!noEmbedCIDTTFonts);
+  psOut->setFontPassthrough(fontPassthrough);
+  psOut->setPreloadImagesForms(preload);
+#if OPI_SUPPORT
+  psOut->setGenerateOPI(doOPI);
+#endif
+  psOut->setUseBinary(psBinary);
+
+  psOut->setRasterAntialias(rasterAntialias);
   if (psOut->isOk()) {
     for (int i = firstPage; i <= lastPage; ++i) {
       doc->displayPage(psOut, i, 72, 72,
